# X-IPE Integration Landscape

## External Systems

Copilot CLI
Tech: Node.js
Platform: Terminal
GitHub
Tech: REST API
Platform: Cloud
MCP Servers
Tech: MCP Protocol
Platform: Local/Cloud

## X-IPE Application

Flask Backend
Tech: Python/Flask
Platform: Local
Web Frontend
Tech: JavaScript
Platform: Browser
WebSocket Terminal
Tech: xterm.js
Platform: Browser

## Skills & Configuration

GitHub Skills
Tech: Markdown
Platform: .github/skills/
Tools Config
Tech: JSON
Platform: x-ipe-docs/config/
Themes
Tech: Markdown/HTML
Platform: docs/themes/

## Storage

🗄️
Project Files
💡
Ideas Folder
📊
Session Data

### Action Flows

Copilot CLI → Flask Backend Execute Commands
Copilot CLI → Terminal Stream Output
GitHub → Skills Load Skills
MCP Servers → Flask Backend Tool Calls
Frontend → Flask Backend API Requests
Frontend → Terminal Terminal Input
Flask Backend → Frontend Render Templates
Flask Backend → Skills Load Task Skills
Flask Backend → Tools Config Read Config
Flask Backend → Themes Apply Themes
Flask Backend → Project Files Read/Write Files
Flask Backend → Ideas Folder Manage Ideas
Flask Backend → Session Data Session State